@@ -343,15 +343,6 @@ cutree_1h.dendrogram <- function(dend, h,
 #' # 134 times faster for a tree of size 150!!
 #' }
 heights_per_k.dendrogram <- function(dend, ...) {
-   fo <- dendextend_options("heights_per_k.dendrogram")   
-   fo(dend, ...)
-}
-
-
-
-#' @export
-dendextend_heights_per_k.dendrogram <- function(dend,...)
-{
    # gets a dendro tree
    # returns a vector of heights, and the k clusters we'll get for each of them.
    
@@ -669,7 +660,9 @@ cutree <- function(tree, k = NULL, h = NULL,...)  {UseMethod("cutree")}
 #' @export
 #' @rdname cutree-methods
 cutree.default <- function(tree, k = NULL, h = NULL,...) {
-   stop("Function cutree is only available for hclust/dendrogram/phylo objects only.")}
+      cutree(as.dendrogram(tree),k=k,h=h,...)
+      # stop("Function cutree is only available for hclust/dendrogram/phylo objects only.")
+   }
 
 #' @export
 #' @rdname cutree-methods
@@ -736,6 +729,21 @@ cutree.hclust <- function(tree, k = NULL, h = NULL,
 cutree.phylo <- function(tree,k=NULL, h=NULL ,...) {cutree(as.dendrogram(tree),k=k,h=h,...)}
    
 
+# ' @S3method cutree phylo
+#' @export
+#' @rdname cutree-methods
+cutree.phylo <- function(tree,k=NULL, h=NULL ,...) {cutree(as.dendrogram(tree),k=k,h=h,...)}
+
+# ' @S3method cutree phylo
+#' @export
+#' @rdname cutree-methods
+cutree.agnes <- function(tree,k=NULL, h=NULL ,...) {cutree(as.dendrogram(tree),k=k,h=h,...)}
+# stats::cutree
+
+#' @export
+#' @rdname cutree-methods
+cutree.diana <- function(tree,k=NULL, h=NULL ,...) {cutree(as.dendrogram(tree),k=k,h=h,...)}
+
 
 # In "cutree.dendrogram" I use "tree" instead of "dend" - in order to stay compatible with stats:cutree
 
