@@ -147,8 +147,6 @@
    
    # dendextend::dendextend_options()
    
-   # set default options for d3 dendrogram.
-   d3dendro_defaults(D3DENDRODEFAULTS)
 }
 
 # menus are added and removed as needed: !!
@@ -407,8 +405,8 @@ dendextendWelcomeMessage <- function(){
 
 # shell('git log --graph --stat --date=short --pretty=format:"%ad(%an) %s |%h" > ChangeLog', intern = TRUE)
 # file.copy("NEWS", "NEWS.md",overwrite = TRUE)
-# devtools::build_win(version="R-release")
-# devtools::build_win(version="R-devel")
+# devtools::check_win()
+# devtools::check_win_devel()
 # release()
 
 
